@@ -87,23 +87,6 @@ def postgres_container():
     network = create_postgres_network(NETWORK_NAME)
     container = create_postgres_container(CONTAINER_NAME, network)
     container.start()
-
-    proc = subprocess.run('docker network ls --format "{{.Name}}"',
-                          shell=True,
-                          check=True,
-                          capture_output=True)
-    names = ' '.join(proc.stdout.decode().strip().split('\n'))
-    proc = subprocess.run(f'docker network inspect {names}',
-                          shell=True,
-                          check=False,
-                          capture_output=True)
-    print(proc.stdout.decode().strip())
-    proc = subprocess.run(f'docker container inspect {CONTAINER_NAME}',
-                          shell=True,
-                          check=True,
-                          capture_output=True)
-    print(proc.stdout.decode().strip())
-
     yield container
     container.stop()
     container.remove()
