@@ -111,9 +111,10 @@ class Relationship(Field):
 class LocalRelationship(Relationship):
     """A relationship with a local foreign key."""
 
-    def __init__(self, rtable, lfkey):
+    def __init__(self, rtable, lfkey, *, nullable=True):
         super().__init__(rtable)
         self.lfkey = lfkey
+        self.nullable = nullable
 
     def filter_condition(self, values):
         uuids = ','.join(
@@ -133,7 +134,11 @@ class LocalRelationship(Relationship):
             foreign key of this object.
         """
 
-        return f'{self.lfkey} UUID'
+        if self.nullable:
+            nullable = ''
+        else:
+            nullable = ' NOT NULL'
+        return f'{self.lfkey} UUID{nullable}'
 
     def __str__(self):
         return self.lfkey
