@@ -273,13 +273,17 @@ class Collection(Resource):
             [f'${index}' for index in range(1, length + 1)])
         stmt = (f'INSERT INTO data.{self.table.name} ({column_names}) '
                 f'VALUES ({column_values})')
+        attribute_values = []
+        for attr_name, value in env.attributes.items():
+            attr = self.table.attributes_by_name[attr_name]
+            attribute_values.append(attr.type_.to_sql(value))
         try:
             async with env.lock:
                 async with env.connection.transaction():
                     log.debug(f'{stmt}: {env.id_number}, '
                               f'{env.attributes.values()}, {lfkey_values}')
                     await env.connection.execute(stmt, env.id_number,
-                                                 *env.attributes.values(),
+                                                 *attribute_values,
                                                  *lfkey_values)
         except ForeignKeyViolationError as exc:
             env.cancel()
