@@ -23,7 +23,6 @@
 from abc import abstractmethod
 from asyncio import Event, Lock, create_task, gather
 from itertools import chain
-from json import loads
 
 from ajsonapi.conversions import id_number_to_name
 from ajsonapi.environments import GetObjectIncludedEnvironment
@@ -35,7 +34,6 @@ from ajsonapi.exceptions import ErrorsException
 from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
 from ajsonapi.responses import document_response
-from ajsonapi.types import Json
 from ajsonapi.uri.collection import Collection
 from ajsonapi.uri.resource import Resource
 
@@ -132,11 +130,8 @@ class ToOneRelatedResource(RelatedResource):
             if col_name == 'id':
                 id_name = id_number_to_name(value)
             elif col_name in self.relationship.rtable.attributes_by_name:
-                col = self.relationship.rtable.attributes_by_name[col_name]
-                if col.type_ == Json:  # Should we use a virtual function?
-                    attributes[col_name] = loads(value)
-                else:
-                    attributes[col_name] = value
+                attr = self.relationship.rtable.attributes_by_name[col_name]
+                attributes[col_name] = attr.type_.from_sql(value)
             else:  # col_name is a lfkey
                 rel = self.relationship.rtable.relationship_by_lfkey[col_name]
                 relationships[rel.name] = self.to_relationships(rel, value)
